@@ -24,8 +24,8 @@ from trosnoth.src.utils.event import Event
 from trosnoth.src.gui.common import AttachedPoint, Location, ScaledLocation, ScaledSize
 
 class CheckBox(Element):
-    def __init__(self, app, pos, text, font, colour, initValue = False,
-                 hotkey = None, style = 'fill'):
+    def __init__(self, app, pos, text, font, colour, initValue=False,
+                 hotkey=None, style='circle', fillColour=None):
         super(CheckBox, self).__init__(app)
 
         self.pos = pos
@@ -42,6 +42,10 @@ class CheckBox(Element):
         
         self.value = initValue
         self.colour = colour
+        if fillColour is None:
+            self.fillColour = tuple((256*3+i)/4 for i in colour)
+        else:
+            self.fillColour = fillColour
         self.hotkey = hotkey
         self.style = style
         self.onValueChanged = Event()
@@ -65,19 +69,18 @@ class CheckBox(Element):
 
     def draw(self, surface):
         box = self._getBoxRect()
-        pygame.draw.rect(surface, self.colour, box, self._getBorderWidth())
         if self.value:
             if self.style == 'fill':
-                pygame.draw.rect(surface, self.colour, box, 0)
-
+                pygame.draw.rect(surface, self.fillColour, box, 0)
             elif self.style == 'cross':
-                pygame.draw.line(surface, self.colour, box.topright, \
+                pygame.draw.line(surface, self.fillColour, box.topright, \
                                  box.bottomleft, self._getBorderWidth())
-                pygame.draw.line(surface, self.colour, box.topleft, \
+                pygame.draw.line(surface, self.fillColour, box.topleft, \
                                  box.bottomright, self._getBorderWidth())
             elif self.style == 'circle':
-                pygame.draw.circle(surface, self.colour, box.center,
+                pygame.draw.circle(surface, self.fillColour, box.center,
                                    box.width / 2 - 2)
+        pygame.draw.rect(surface, self.colour, box, self._getBorderWidth())
             
         self.text.draw(surface)
 
@@ -89,7 +92,7 @@ class CheckBox(Element):
     def processEvent(self, event):
         box = self._getBoxRect()
         # Active events.
-        if (event.type == pgl.MOUSEBUTTONDOWN and \
+        if (event.type == pgl.MOUSEBUTTONDOWN and event.button == 1 and \
                 box.collidepoint(event.pos)) or \
                 (event.type == pgl.KEYDOWN and event.key == self.hotkey):
             self.setValue(not self.value)
