@@ -15,15 +15,20 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301, USA.
 
+import platform
 import pygame
+from twisted.internet import reactor
 
 import screenFonts
 from trosnoth.src.gui.framework import framework
 from trosnoth.src.gui.common import Location
-from twisted.internet import reactor
+from trosnoth.src.utils.logging import writeException
 
-class TerminateHotKey(framework.Element):
-    '''Traps a Ctrl+Break / Ctrl+Pause keypress and terminates the game.'''
+class SystemHotKeys(framework.Element):
+    '''
+    Traps a Ctrl+Break / Ctrl+Pause keypress and terminates the game.
+    Traps an Alt+Tab keypress and minimises the game.
+    '''
     def processEvent(self, event):
         if event.type == pygame.KEYDOWN:
             if event.key in (pygame.K_SCROLLOCK, pygame.K_BREAK, pygame.K_PAUSE) and (event.mod & pygame.KMOD_CTRL):
@@ -34,8 +39,27 @@ class TerminateHotKey(framework.Element):
                 print 'Trapped Ctrl+Meta+Backslash: Quitting.'
                 self.app.stop()
                 return None
+            if event.key == pygame.K_TAB and (event.mod & pygame.KMOD_ALT) and self.app.screenManager.isFullScreen():
+                if platform.system() != 'Darwin':
+                    # Minimise.
+                    pygame.display.iconify()
+                return None
         return event
 
+class Pointer(framework.CompoundElement):
+    def __init__(self, app, element):
+        super(Pointer, self).__init__(app)
+        assert hasattr(element, 'setPos')
+        self.elements = [element]
+
+    def draw(self, screen):
+        try:
+            pos = pygame.mouse.get_pos()
+            self.elements[0].setPos(Location(pos, 'center'))
+        except:
+            writeException()
+        super(Pointer, self).draw(screen)
+        
 class ScreenManager(framework.CompoundElement):
     '''Manages everything to do with the screen, especially any scaling due
     to the size of the screen.'''
@@ -48,7 +72,7 @@ class ScreenManager(framework.CompoundElement):
         self.fonts = screenFonts.ScreenFonts()
         self.pointer = None
         self.interface = None
-        self.terminator = TerminateHotKey(self.app)
+        self.terminator = SystemHotKeys(self.app)
         self.elements = [self.terminator]
 
     def setPointer(self, pointer):
@@ -56,7 +80,7 @@ class ScreenManager(framework.CompoundElement):
         self.elements.remove(self.terminator)
         if self.pointer is not None and self.pointer in self.elements:
             self.elements.remove(self.pointer)
-        self.pointer = pointer
+        self.pointer = Pointer(self.app, pointer)
         self.elements.append(self.pointer)
         self.elements.append(self.terminator)
         
@@ -112,11 +136,4 @@ class ScreenManager(framework.CompoundElement):
         of that ratio that fits within this screen.'''
         return (int(point[0] * self.scaleFactor + self.offsets[0]),
                 int(point[1] * self.scaleFactor + self.offsets[1]))
-    
 
-    def tick(self, deltaT):
-        # Update the mouse pointer position.
-        if self.pointer is not None:
-            self.pointer.setPos(Location(pygame.mouse.get_pos(), 'center'))
-
-        super(ScreenManager, self).tick(deltaT)
