@@ -51,7 +51,7 @@ defaultKeys = (
     ('captain', pygame.K_c),
     ('team ready', pygame.K_y),
     ('leaderboard', pygame.K_p),
-    ('toggle interface', pygame.K_TAB),
+    ('toggle interface', pygame.K_DELETE),
 )
 
 default_game_keys = VirtualKeySet(defaultKeys)
