@@ -20,11 +20,8 @@ from trosnoth.src.utils.components import Message
 class Killing(Message):
     fields = 'target', 'killer', 'shot', 'xPos', 'yPos'
 
-class TaggingZone(Message):
-    fields = 'zone', 'player', 'team'
-
 class PlayerKilled(Message):
-    fields = 'target', 'killer'
+    fields = 'target', 'killer', 'shot'
 
 class TaggedZone(Message):
     fields = ('zone', 'player')
