@@ -19,15 +19,14 @@
 the running of the universe. The server should never require pygame to be
 imported.'''
 
-from math import sin, cos, pi
 import struct
 import random
 
 from twisted.internet import reactor
 
-from trosnoth.src.utils.utils import timeNow, new
+from trosnoth.src.utils.utils import timeNow
+from trosnoth.src.utils.checkpoint import checkpoint
 from trosnoth.src.model import modes
-from trosnoth.src.utils import logging
 from trosnoth.src.model.universe_base import GameState
 from trosnoth.src.model.transaction import TransactionState
 
@@ -191,7 +190,6 @@ class Universe(object):
         
         totalWidth = halfMapWidth * 2 + 1
         middleHeight = ((halfMapWidth - 1) % 2) + 1 + mapHeight
-        zonesPerTeam = halfMapWidth * mapHeight + halfMapWidth / 2
         
         if middleHeight == mapHeight + 2:
             self.highExists = True
@@ -288,9 +286,6 @@ class Universe(object):
         # numSoFar keeps track of the number of zones created so far.
         numSoFar = 0
 
-        # prevCol (previous Column) tells how high the previous column was.
-        prevCol = None
-
         ''' To calculate adjacent zones, the zones were conceptualised in the
          following pattern, counting downwards by column, then left to right:
          (assuming mapHeight = 3, halfMapWidth = 2)
@@ -409,10 +404,6 @@ class Universe(object):
             # Make sure that the bottom zone in each column has a floor.
             self.zoneBlocks[startRow+1][startCol+1].blocked = True
 
-            # Reset for next column:    
-            prevCol = height
-            prevColHeight = colHeight
-
             # Advance x-coordinate.
             xCoord = xCoord + self.zoneBodyWidth + self.zoneInterfaceWidth
 
@@ -479,6 +470,7 @@ class Universe(object):
 
         winner = Team.determineWinner(self.teams[0], self.teams[1])
         self.netServer.gameOver(winner, True)
+        checkpoint('ServerUniverse: time has run out')
 
 
         
@@ -494,6 +486,7 @@ class Universe(object):
             for team in self.teams:
                 if team.checkWon():
                     self.netServer.gameOver(team)
+                    checkpoint('ServerUniverse: team has won')
                     if self.timeOutCaller is not None:
                         self.timeOutCaller.cancel()
                     return
@@ -967,14 +960,14 @@ class Player(object):
             # Must have just been a validation
             pass
 
-    def removeStars(self, stars):
+    def subtractStars(self, stars):
         if self.universe.netServer.settings['testMode']:
             return
         self.stars -= stars
         if self.stars < 0:
             print 'OH NOES! Self.stars < 0. %s %s' % (self.stars, stars)
             self.stars = 0
-        print 'player now has %s stars' % self.stars
+        print '%s now has %s stars' % (self.nick, self.stars)
 
     def changeZone(self, newZone):
         if newZone != self.currentZone:
