@@ -92,12 +92,10 @@ class DetailsInterface(framework.CompoundElement):
     def showSettings(self):
         if self.settingsMenu not in self.elements:
             self.elements.append(self.settingsMenu)
-            self.gameInterface.allowMouseGrab(False)
 
     def hideSettings(self):
         if self.settingsMenu in self.elements:
             self.elements.remove(self.settingsMenu)
-            self.gameInterface.allowMouseGrab(True)
             self.gameInterface.updateKeyMapping()
 
     def _getUpgrade(self, stars, upgrade):
