@@ -96,15 +96,6 @@ class GameInterface(framework.CompoundElement, Component):
         self.elements = [self.gameViewer,
                          pi, self.menuHotkey, self.hotkeys, self.detailsInterface]
 
-    def allowMouseGrab(self, allow):
-        '''
-        Called by details interface when the settings screen is shown to
-        indicate that mouse grabbing should not be performed.
-        '''
-        if self.runningPlayerInterface is not None:
-            self.runningPlayerInterface.allowMouseGrab(allow)
-
-
     def showMenu(self):
         if self.runningPlayerInterface is not None:
             if self.runningPlayerInterface.player is not None:
