@@ -33,68 +33,23 @@ class PlayerInterface(framework.Element):
         self.keyMapping = gameInterface.keyMapping
 
         self.receiving = True
-        self.canGrabMouse = True
 
         self.world = world
         self.playerSprite = playerSprite
         self.player = playerSprite.player
         rect = pygame.Rect((0,0), self.app.screenManager.scaledSize)
 
-        self.crosshairsLocked = False
         self.mousePos = (0, 0)
         pygame.mouse.get_rel()
 
         # Make sure the viewer is focusing on this player.
         self.gameInterface.gameViewer.setTarget(playerSprite)
 
-    def allowMouseGrab(self, allow):
-        '''
-        Called by game interface when the settings screen is shown to
-        indicate that mouse grabbing should not be performed.
-        '''
-        self.canGrabMouse = allow
-        relPos = pygame.mouse.get_rel()
-
     def tick(self, deltaT):
-        if not (self.app.screenManager.isFullScreen() and self.canGrabMouse):
-            pos = pygame.mouse.get_pos()
-            spritePos = self.playerSprite.rect.center
-            self.mousePos = (pos[0] - spritePos[0], pos[1] - spritePos[1])
-            self.updatePlayerViewAngle()
-            return
-        relPos = pygame.mouse.get_rel()
-        #if relPos == (0, 0):
-        #    return
-
-        self.mousePos = (self.mousePos[0] + relPos[0],
-                         self.mousePos[1] + relPos[1])
-        self.updatePlayerViewAngle()
-
-        if self.crosshairsLocked:
-            # Place the cursor.
-            radius = (self.mousePos[0]**2 + self.mousePos[1]**2)**0.5
-            if radius > 160:
-                radius = 160
-                angle = self.player.angleFacing
-                self.mousePos = (radius * sin(angle),
-                                 -radius * cos(angle))
-
-        # Bound the new mouse position.
+        pos = pygame.mouse.get_pos()
         spritePos = self.playerSprite.rect.center
-        if self.app.screenManager.isFullScreen():
-            screenSize = self.app.screenManager.size
-            self.mousePos = (
-                max(-spritePos[0],
-                    min(screenSize[0]-spritePos[0], self.mousePos[0])),
-                max(-spritePos[1],
-                    min(screenSize[1]-spritePos[1], self.mousePos[1]))
-            )
-
-        # Set the new mouse position.
-        pygame.mouse.set_pos(int(spritePos[0] + self.mousePos[0] + 0.5),
-                             int(spritePos[1] + self.mousePos[1] + 0.5))
-        pygame.mouse.get_rel()
-
+        self.mousePos = (pos[0] - spritePos[0], pos[1] - spritePos[1])
+        self.updatePlayerViewAngle()
         
     def updatePlayerViewAngle(self):
         '''Updates the viewing angle of the player based on the mouse pointer
@@ -161,16 +116,5 @@ class PlayerInterface(framework.Element):
                     else:
                         # Fire a shot.
                         self.player.fireShot()
-                elif event.button == 3:     # Right button.
-                    if not self.app.screenManager.isFullScreen():
-                        msg = 'Cannot lock crosshairs out of full screen mode'
-                    else:
-                        self.crosshairsLocked = not self.crosshairsLocked
-                        if self.crosshairsLocked:
-                            msg = 'Crosshairs locked. Right-click to unlock.'
-                        else:
-                            msg = 'Crosshairs unlocked.'
-                    self.gameInterface.detailsInterface.newMessage(msg)
-                    
             else:
                 return event
