@@ -27,8 +27,11 @@ import pygame
 class TransactionGUI(framework.Element):
     '''Shows current Transaction information on screen'''
     buffer = 20
+    
     def __init__(self, app, pos, transaction, player, bigFont = None, midFont = None, smallFont = None, bgColour = (0,0,255), foreColour = (255,255,255)):
         super(TransactionGUI, self).__init__(app)
+
+        self.minWidth = 320 * app.screenManager.scaleFactor
         self.player = player
         self.pos = pos
         self.transaction = transaction
@@ -52,11 +55,12 @@ class TransactionGUI(framework.Element):
         self.bgColour = bgColour
         self.foreColour = foreColour
         self.borderColour = (0,0,0)
-        self._purchasingText = '%s purchasing %s' % (self.transaction.purchasingPlayer.nick, upgradeNames[self.transaction.upgrade])
 
-
-##        self.transaction.onNumStarsChanged.addListener(transactionChanged)
-##        self.transaction.onStateChanged.addListener(stateChanged)
+        self.transPlayer = self.transaction.purchasingPlayer.nick
+        self.transUpgrade = upgradeNames[self.transaction.upgrade]
+        self._purchasingText = '%s purchasing %s' % (self.transPlayer, self.transUpgrade)
+        self._purchasedText = '%s purchased %s' % (self.transPlayer, self.transUpgrade)
+        self._purchaseFailedText = 'Purchase of %s failed' % self.transUpgrade
 
     # Find the largest size that this box should become
     # This function assumes that all numbers are the same width
@@ -65,7 +69,7 @@ class TransactionGUI(framework.Element):
         fontSize1 = self.bigFont.size(self.app, "00 of %d" % (self.starsRqd))
         fontSize2 = self.midFont.size(self.app, self._purchasingText)
         fontSize3 = self.smallFont.size(self.app, "You have contributed 10 stars")
-        width = max(fontSize1[0], fontSize2[0], fontSize3[0]) + self.buffer
+        width = max(max(fontSize1[0], fontSize2[0], fontSize3[0]) + self.buffer, self.minWidth)
         height = fontSize1[1] + fontSize2[1] + fontSize3[1] + self.buffer
         
         return (width, height)
@@ -121,6 +125,23 @@ class TransactionGUI(framework.Element):
     def _drawCompleted(self, surface):
         
         reason = transactionModule.TransactionStateText[self.transaction.state]
-        images = [self.bigFont.render(self.app, "Transaction", True, self.foreColour, self.bgColour),
-                  self.bigFont.render(self.app, reason, True, self.foreColour, self.bgColour)]
-        self._drawTexts(surface, images)
\ No newline at end of file
+        images = [self.bigFont.render(self.app, "Transaction %s" % reason, True, self.foreColour, self.bgColour)]
+
+        if reason == 'Completed':
+            images.append(self.midFont.render(self.app, self._purchasedText, True, self.foreColour, self.bgColour))
+        else:
+            if self.transaction.abandonReason == 'time':
+                reasonText = "Transaction took too long"
+            elif self.transaction.abandonReason == 'request':
+                reasonText = "%s cancelled the transaction" % self.transPlayer
+            elif self.transaction.abandonReason == 'death':
+                reasonText = "%s was killed" % self.transPlayer
+            elif self.transaction.abandonReason == 'stars':
+                reasonText = "There are no longer enough stars available"
+            else:                
+                reasonText = "(reason unknown) - [%s]" % (self.transaction.abandonReason,)
+
+            images.append(self.midFont.render(self.app, self._purchaseFailedText, True, self.foreColour, self.bgColour))
+            images.append(self.smallFont.render(self.app, reasonText, True, self.foreColour, self.bgColour))
+            
+        self._drawTexts(surface, images)
