@@ -21,49 +21,47 @@ from trosnoth.src.gui.framework.elements import TextElement, TextButton
 from trosnoth.src.gui.framework.checkbox import CheckBox
 from trosnoth.src.gui.framework.tab import Tab
 import trosnoth.src.gui.framework.prompt as prompt
-import trosnoth.src.trosnothgui.pregame.colours as colours
+from trosnoth.src.trosnothgui.pregame.common import button
 from trosnoth.src.trosnothgui import defines
 from trosnoth.src.gui.common import *
+from trosnoth.src.utils.event import Event
 
 
 class DisplaySettingsTab(Tab, framework.TabFriendlyCompoundElement):
-    def __init__(self, app, startupInterface):
+    def __init__(self, app, onClose=None):
         super(DisplaySettingsTab, self).__init__(app, 'Display')
-        self.startupInterface = startupInterface
 
-        button = startupInterface.button
+        self.onClose = Event()
+        if onClose is not None:
+            self.onClose.addListener(onClose)
 
         font = self.app.screenManager.fonts.bigMenuFont
         smallNoteFont = self.app.screenManager.fonts.smallNoteFont
 
+        colour = self.app.theme.colours.headingColour
+        def mkText(text, x, y, textFont=font, anchor='topright'):
+            return TextElement(self.app, text, textFont,
+                    ScaledLocation(x, y, anchor),
+                    colour)
+
         self.text = [
-                     TextElement(self.app, 'X', font,
-                                 ScaledLocation(630, 310, 'topright'),
-                                 colours.headingColour),
-                     TextElement(self.app, 'Screen Resolution', font,
-                                 ScaledLocation(400, 310, 'topright'),
-                                 colours.headingColour),
-                     TextElement(self.app, 'Fullscreen Mode', font,
-                                 ScaledLocation(400, 380,'topright'),
-                                 colours.headingColour),
-                     TextElement(self.app, 'Use Alpha Channel', font,
-                                 ScaledLocation(400, 450,'topright'),
-                                 colours.headingColour),
-                     TextElement(self.app, 'Deselect this option if Ghosts or Phase Shift',
-                                 smallNoteFont,
-                                 ScaledLocation(520, 455,'topleft'),
-                                 colours.headingColour),
-                     TextElement(self.app, 'cause your framerate to go down.',
-                                 smallNoteFont,
-                                 ScaledLocation(520, 485,'topleft'),
-                                 colours.headingColour),
-                                 ]
+            mkText('X', 630, 250),
+            mkText('Screen Resolution', 400, 250),
+            mkText('Fullscreen Mode', 400, 320),
+            mkText('Use Alpha Channel', 400, 390),
+            mkText('Deselect this option if Ghosts or Phase Shift', 520, 395,
+                    smallNoteFont, 'topleft'),
+            mkText('cause your framerate to go down.', 520, 425,
+                    smallNoteFont, 'topleft'),
+            mkText('Smooth Panning', 400, 460),
+            mkText('Centre on Player', 400, 530),
+        ]
 
         self.invalidInputText = TextElement(self.app, '', font,
-                                            ScaledLocation(512, 245,'midtop'),
+                                            ScaledLocation(512, 185,'midtop'),
                                             (192, 0,0))
 
-        self.widthInput = prompt.InputBox(self.app, ScaledArea(450, 310, 150, 60),
+        self.widthInput = prompt.InputBox(self.app, ScaledArea(450, 240, 150, 60),
                                           initValue = str(self.app.screenManager.size[0]),
                                           font = font,
                                           maxLength = 4,
@@ -73,7 +71,7 @@ class DisplaySettingsTab(Tab, framework.TabFriendlyCompoundElement):
         self.widthInput.onClick.addListener(self.setFocus)
         self.widthInput.onTab.addListener(self.tabNext)
 
-        self.heightInput = prompt.InputBox(self.app, ScaledArea(642, 310, 150, 60),
+        self.heightInput = prompt.InputBox(self.app, ScaledArea(642, 240, 150, 60),
                                           initValue = str(self.app.screenManager.size[1]),
                                           font = font,
                                           maxLength = 4,
@@ -85,27 +83,41 @@ class DisplaySettingsTab(Tab, framework.TabFriendlyCompoundElement):
 
         self.tabOrder = [self.widthInput, self.heightInput]
         
-        self.fullscreenBox = CheckBox(self.app, ScaledLocation(450, 390),
+        self.fullscreenBox = CheckBox(self.app, ScaledLocation(450, 330),
                                              text = '',
                                              font = font,
                                              colour = (192,192,192),
                                              initValue = self.app.screenManager.isFullScreen())
         self.fullscreenBox.onValueChanged.addListener(self.fullscreenChanged)
 
-        self.alphaBox = CheckBox(self.app, ScaledLocation(450, 460),
+        self.alphaBox = CheckBox(self.app, ScaledLocation(450, 400),
                                  text = '',
                                  font = font,
                                  colour = (192,192,192),
                                  initValue = defines.useAlpha)
         
-        self.input = [self.widthInput, self.heightInput, self.widthInput, self.fullscreenBox, self.alphaBox]
+        self.panningBox = CheckBox(self.app, ScaledLocation(450, 470),
+                                 text = '',
+                                 font = font,
+                                 colour = (192,192,192),
+                                 initValue = app.displaySettings.smoothPanning)
+        
+        self.centreOnPlayerBox = CheckBox(self.app, ScaledLocation(450, 530),
+                                 text = '',
+                                 font = font,
+                                 colour = (192,192,192),
+                                 initValue = app.displaySettings.centreOnPlayer)
+
+        self.input = [self.widthInput, self.heightInput, self.widthInput,
+                self.fullscreenBox, self.alphaBox, self.panningBox,
+                self.centreOnPlayerBox]
         
         self.elements = self.text + self.input + \
                         [self.invalidInputText,
-                         button('save',
+                         button(app, 'save',
                                 self.saveSettings,
                                 (-100, -75), 'midbottom'),
-                         button('cancel',
+                         button(app, 'cancel',
                                 self.cancelMenu,
                                 (100, -75), 'midbottom'),
                          ]
@@ -115,19 +127,24 @@ class DisplaySettingsTab(Tab, framework.TabFriendlyCompoundElement):
     def cancelMenu(self):
         self.fullscreenBox.setValue(self.app.screenManager.isFullScreen())
         self.alphaBox.setValue(defines.useAlpha)
+        self.panningBox.setValue(self.app.displaySettings.smoothPanning)
+        self.centreOnPlayerBox.setValue(self.app.displaySettings.centreOnPlayer)
         self.heightInput.setValue(str(self.app.screenManager.size[1]))
         self.widthInput.setValue(str(self.app.screenManager.size[0]))
 
-        self.startupInterface.mainMenu()
+        self.onClose.execute()
 
     def saveSettings(self):
         values = self.getValues()
         if values is not None:
-            screenSize, fullScreen, useAlpha = values
+            screenSize, fullScreen, useAlpha, smoothPanning, centreOnPlayer = \
+                values
 
             # Save these values.
             self.app.displaySettings.fullScreen = fullScreen
             self.app.displaySettings.useAlpha = useAlpha
+            self.app.displaySettings.smoothPanning = smoothPanning
+            self.app.displaySettings.centreOnPlayer = centreOnPlayer
             if fullScreen:
                 self.app.displaySettings.fsSize = screenSize
             else:
@@ -137,7 +154,7 @@ class DisplaySettingsTab(Tab, framework.TabFriendlyCompoundElement):
             self.app.displaySettings.save()
             self.app.displaySettings.apply()
 
-            self.startupInterface.mainMenu()
+            self.onClose.execute()
 
     def getValues(self):
 
@@ -145,6 +162,8 @@ class DisplaySettingsTab(Tab, framework.TabFriendlyCompoundElement):
         width = self.getInt(self.widthInput.value)
         fullScreen = self.fullscreenBox.value
         useAlpha = self.alphaBox.value
+        smoothPanning = self.panningBox.value
+        centreOnPlayer = self.centreOnPlayerBox.value
 
         # The resolutionList is used when fullScreen is true.
         resolutionList = pygame.display.list_modes()
@@ -184,7 +203,7 @@ class DisplaySettingsTab(Tab, framework.TabFriendlyCompoundElement):
 
         self.incorrectInput('')
 
-        return [(width, height), fullScreen, useAlpha]
+        return (width, height), fullScreen, useAlpha, smoothPanning, centreOnPlayer
 
     def getInt(self, value):
         if value == '':
@@ -193,7 +212,7 @@ class DisplaySettingsTab(Tab, framework.TabFriendlyCompoundElement):
         
     def incorrectInput(self, string):
         self.invalidInputText.setText(string)
-        self.invalidInputText.setFont(self.startupInterface.font)
+        self.invalidInputText.setFont(self.app.screenManager.fonts.bigMenuFont)
 
     def fullscreenChanged(self, element):
         # If the resolution boxes haven't been touched, swap their values to
