@@ -20,13 +20,13 @@ from trosnoth.src.gui.framework.tab import Tab
 from trosnoth.src.gui.framework.tabContainer import TabSize
 from trosnoth.src.gui.framework.listbox import ListBox
 from trosnoth.src.gui.framework.elements import TextElement, TextButton
-from trosnoth.src.trosnothgui.pregame import colours
 from trosnoth.src.network.networkDefines import validServerVersions
 from trosnoth.src.gui.common import *
 
 class LanTab(Tab):
     def __init__(self, app, tabContainer, startupInterface):
         super(LanTab, self).__init__(app, 'Games')
+        colours = app.theme.colours
         self.startupInterface = startupInterface
         self.tabContainer = tabContainer
         tabSize = TabSize(tabContainer)
@@ -60,8 +60,11 @@ class LanTab(Tab):
                          ]
         
     def button(self, text, onClick, pos, anchor='topleft'):
-        pos = Location(AttachedPoint(pos,self.tabContainer._getTabRect, anchor), anchor)
-        result = TextButton(self.app, pos, text, self.startupInterface.font, colours.mainMenuColour, colours.white)
+        pos = Location(AttachedPoint(pos,self.tabContainer._getTabRect, anchor),
+                anchor)
+        result = TextButton(self.app, pos, text, self.startupInterface.font,
+                self.app.theme.colours.mainMenuColour,
+                self.app.theme.colours.white)
         result.onClick.addListener(lambda sender: onClick())
         return result
 
