@@ -23,7 +23,6 @@ from trosnoth.src.gui.common import *
 from trosnoth.src.trosnothgui.pregame.lanTab import LanTab
 from trosnoth.src.trosnothgui.pregame.internetTab import InternetTab
 from trosnoth.src.trosnothgui.pregame.serverSetupTab import ServerSetupTab
-from trosnoth.src.trosnothgui.pregame import colours
 from trosnoth.src.trosnothgui import defines
 
 class PlayMenu(framework.CompoundElement):
@@ -37,7 +36,8 @@ class PlayMenu(framework.CompoundElement):
         if defines.useAlpha:
             bg.set_alpha(192)
         
-        self.tabContainer = TabContainer(self.app, area, startupInterface.font, colours.tabContainerColour)
+        self.tabContainer = TabContainer(self.app, area, startupInterface.font,
+                app.theme.colours.tabContainerColour)
         bp = SizedPicture(app, bg, Location(AttachedPoint((0,0),self.tabContainer._getTabRect)), TabSize(self.tabContainer))
         
         lanTab = LanTab(app, self.tabContainer, startupInterface)
@@ -55,7 +55,9 @@ class PlayMenu(framework.CompoundElement):
         
     def button(self, text, onClick, pos, anchor='topleft'):
         pos = Location(AttachedPoint(ScaledSize(*pos),self.tabContainer._getTabRect, anchor), anchor)
-        result = TextButton(self.app, pos, text, self.startupInterface.font, colours.mainMenuColour, colours.white)
+        result = TextButton(self.app, pos, text, self.startupInterface.font,
+                self.app.theme.colours.mainMenuColour,
+                self.app.theme.colours.white)
         result.onClick.addListener(lambda sender: onClick())
         return result
     
